@@ -1,8 +1,10 @@
 #![allow(clippy::integer_arithmetic)]
+pub use solana_test_validator as test_validator;
 use {
     console::style,
     fd_lock::{RwLock, RwLockWriteGuard},
     indicatif::{ProgressDrawTarget, ProgressStyle},
+    solana_net_utils::MINIMUM_VALIDATOR_PORT_RANGE_WIDTH,
     std::{
         borrow::Cow,
         env,
@@ -13,10 +15,6 @@ use {
         thread::JoinHandle,
     },
 };
-pub use {
-    solana_gossip::cluster_info::MINIMUM_VALIDATOR_PORT_RANGE_WIDTH,
-    solana_test_validator as test_validator,
-};
 
 pub mod admin_rpc_service;
 pub mod bootstrap;
